%MDDS (Mixed Directional Difference-Summation) package
% 
%1. Demonstration.
%   demo_mdds2d            - Demo of Bezier net computation, 
%                            exact evaluation and visualization 
%                            of bivariate three-direction Box-splines.
%   demo_mdds3d            - Demo of Bezier net computation, 
%                            exact evaluation and visualization 
%                            of trivariate four-direction Box-splines.
% 
%2. B-net computation.    
%   bnet_mdds              - Computation of the Bezier net coefficients 
%                            of an arbitrary bivariate three-direction/
%                            trivariate four-direction Box-spline. 
%
%   2.1. Bivariate three-direction Box-splines.
%        Mixed directions generation.
%        step1_mdds2d      - Computation of differences-summations along 
%                            direction e_1=[1 0]'. 
%        step2_mdds2d      - Computation of differences-summations along 
%                            direction e_2=[0 1]'.
%        step3_mdds2d      - Computation of differences-summations along 
%                            direction e_12=[1 1]'. 
%  
%   2.2. Trivariate four-direction Box-splines.
%        Mixed directions generation.
%        step1_mdds3d      - Computation of differences-summations along 
%                            direction e_1=[1 0 0]'. 
%        step2_mdds3d      - Computation of differences-summations along 
%                            direction e_3=[0 0 1]'. 
%        step3_mdds3d      - Computation of differences-summations along 
%                            direction e_2=[0 1 0]'. 
%        step4_mdds3d      - Computation of differences-summations along 
%                            direction e_123=[1 1 1]'. 
% 
%   2.3. Functions used in the generation of the mixed directions both 
%        in bivariate and trivariate cases.
%        dupl_mdds         - Duplication of some coefficients of the  
%                            main direction.
%        integ_mdds        - Computation of antidifferences (summations) 
%                            on the coefficients.
% 
%3. Box-splines evaluation.
%   3.1. Bivariate Box-splines evaluation.         
%        pointeval_mdds2d  - Exact evaluation of bivariate three-direction 
%                            Box-splines in an arbitrary set of 2D points. 
%        findsquare_mdds2d - Determination of the unit square containing 
%                            the 2D evaluation point chosen in the 
%                            Box-spline domain. 
%        findtria_mdds2d   - Determination of the triangle type, down ("1") 
%                            or up ("2"), (see [1]) containing the 2D 
%                            evaluation point. 
%     
%   3.2. Trivariate Box-splines evaluation.         
%        pointeval_mdds3d  - Exact evaluation of trivariate four-direction 
%                            Box-splines in an arbitrary set of 3D points.  
%        findcube_mdds3d   - Determination of the unit cube containing  
%                            the 3D evaluation point chosen in the  
%                            Box-spline domain. 
%        findtetra_mdds3d  - Determination of the tetrahedron type, 
%                            "1", "2", "3", "4", "5" or "6" (see [1]) 
%                            containing the 3D evaluation point.
%     
%4. Box-splines visualization.
%   4.1. Bivariate Box-splines visualization.
%        visual_mdds2d     - Visualization of an arbitrary bivariate 
%                            three-direction Box-spline either through 
%                            its surface graph or its B-net representation.
%        computebez_mdds2d - Evaluation of Bernstein-Bezier polynomials 
%                            on a regular triangular grid.
%
%   4.2. Trivariate Box-splines visualization.
%        visual_mdds3d     - Visualization of an arbitrary trivariate 
%                            four-direction Box-spline M_D  
%                            either through the s-set (s in Imm(M_D))  
%                            extraction of the Box-spline volume or through   
%                            the contour lines of the regions obtained by   
%                            intersecting the Box-spline volume with three   
%                            families of planes respectively parallel to yz, 
%                            xz, xy.
%        computebez_mdds3d - Evaluation of Bernstein-Bezier polynomials 
%                            on a regular tetrahedral grid.

%<Reference>
% [1] G. Casciola, E. Franchini, L. Romani, "The mixed directional 
%     difference-summation algorithm for generating the Bezier net of a 
%     trivariate four-direction Box-spline"
%     Numerical Algorithms 43 (2006), pp. 75-98.
%
%<Authors>
% G. Casciola, Dept. of Mathematics - University of Bologna, Italy
% E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
% L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
% Last revision: March 2006
