function [r,c,xu,yu] = findsquare_mdds2d(x,y,mx,my)
%findsquare_mdds2d --> Determination of the unit square containing 
%                      the 2D evaluation point chosen in the 
%                      Box-spline domain.
%
%<Synopsis>
%  [r,c,xu,yu] = findsquare_mdds2d(x,y,mx,my)
%
%<Description>
%  Determine in which unit square of the bivariate Box-spline  
%  domain the evaluation point is contained.
%
%<Input Parameters>
%  x  --> first coordinate of the evaluation point
%   
%  y  --> second coordinate of the evaluation point
%  
%  mx --> maximal value that the first coordinate of an 
%         arbitrary evaluation point could assume
%
%  my --> maximal value that the second coordinate of an 
%         arbitrary evaluation point could assume
%
%<Output Parameters>
%  r  --> row index that identifies the rows in the 
%         B-net coefficients matrix containing
%         the two triangular Bezier patches 
%         defined in the specified square region
%
%  c  --> column index that identifies the columns in the
%         B-net coefficients matrix containing 
%         the two triangular Bezier patches 
%         defined in the specified square region
%
%  xu --> value of the first coordinate (x) of the  
%         evaluation point mapped in [0,1]
%
%  yu --> value of the second coordinate (y) of the 
%         evaluation point mapped in [0,1]  

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

c=floor(x)+1;
xu=x-floor(x);
if x==mx
   c=c-1;
   xu=xu+1;
end
r=my-floor(y);
yu=y-floor(y);
if y==my
   r=r+1;
   yu=yu+1;
end