function [tria,r,s,t] = findtria_mdds2d(x,y)
%findtria_mdds2d --> Determination of the triangle type containing 
%                    the 2D evaluation point chosen in the 
%                    Box-spline domain.
%
%<Synopsis>
%  [tria,r,s,t] = findtria_mdds2d(x,y)
%
%<Description>
%  Determine in which triangle of the bivariate Box-spline  
%  domain the evaluation point is contained.
%
%<Input Parameters>
%  x    --> first coordinate of the evaluation point 
%           mapped in [0,1]
%   
%  y    --> second coordinate of the evaluation point
%           mapped in [0,1] 
%
%<Output Parameters>
%  tria --> triangle type (down or up) containing the 
%           evaluation point
%
%  r    --> first barycentric coordinate of the evaluation
%           point in the identified triangle
%
%  s    --> second barycentric coordinate of the evaluation
%           point in the identified triangle
%
%  t    --> third barycentric coordinate of the evaluation
%           point in the identified triangle 

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

if (y-x)>=0
    % Triangle type "down"
    tria=1;
    % Barycentric coordinates computation
    r=1-y;
    s=x;
    t=y-x;
else
    % Triangle type "up"
    tria=2;
    % Barycentric coordinates computation
    r=1-x;
    s=y;
    t=x-y;
end